@@ -709,10 +709,10 @@ function cwwdrawAppointment(calendarobject) {
 		        }
 									
 				// setting confirmation styles
-				if (calendarobject.participants.length) {
-					for (var i in calendarobject.participants) {
-						if (calendarobject.participants[i].id == owner) {
-							switch(calendarobject.participants[i].confirmation) {
+				if (calendarobject.users.length) {
+					for (var i in calendarobject.users) {
+						if (calendarobject.users[i].id == owner) {
+							switch(calendarobject.users[i].confirmation) {
 								case 0:
 									myappointment.style.opacity = ".6";
 									title.style.fontStyle = "italic";
@@ -937,10 +937,10 @@ function cwwdrawAppointment(calendarobject) {
 		                }
 						
 						// setting confirmation styles
-						if (calendarobject.participants.length) {
-							for (var i in calendarobject.participants) {
-								if (calendarobject.participants[i].id == owner) {
-									switch(calendarobject.participants[i].confirmation) {
+						if (calendarobject.users.length) {
+							for (var i in calendarobject.users) {
+								if (calendarobject.users[i].id == owner) {
+									switch(calendarobject.users[i].confirmation) {
 										case 0:
 											myappointment.style.opacity = ".6";
 											title.style.fontStyle = "italic";
