@@ -365,11 +365,11 @@ ox.categories.ui.close = function(cancel) {
         var grid = ox.categories.ui.grid;
         // iterate through storage and get selected cats 
         grid.storage.newIterate(grid.storage.ids, emptyFunction, function(id, obj) {
-            if (obj) {                
+            if (obj) {
                 if (obj.active) {
                     selCat.push(obj);
                 }
-                if (obj.color !== 0) {
+                if (obj.color !== 0 || ox.categories.exists(obj.name)) {
                     finCat.push(obj);
                 }
                 delete(obj.active); // just temp so delete
