@@ -37,14 +37,29 @@ register("OX_Configuration_Loaded", function() {
 	}
 	if (!configContainsKey("folder"))  {
 		configSetKey("folder",{});	
-	}	
- 	if (!configContainsKey("modules.tasks.notifyNewModifiedDeleted")) {
-		configSetKey("modules.tasks.notifyNewModifiedDeleted",false);
-    }
-    if (!configContainsKey("modules.tasks.notifyAcceptedDeclinedAsParticipant")) {
-    	configSetKey("modules.tasks.notifyAcceptedDeclinedAsParticipant",true);
-    	configuration_changed_fields["module"]=true;
-    }
+	}
+	if (ox.api.config.get("modules.tasks.module", false) === true) {
+	    if (!configContainsKey("modules.tasks.notifyNewModifiedDeleted")) {
+	        configSetKey("modules.tasks.notifyNewModifiedDeleted",false);
+	    }
+	    if (!configContainsKey("modules.tasks.notifyAcceptedDeclinedAsParticipant")) {
+	        configSetKey("modules.tasks.notifyAcceptedDeclinedAsParticipant",true);
+	        configuration_changed_fields["module"]=true;
+	    }
+	    if (!configContainsKey("gui.tasks.view")) {
+	        configSetKey("gui.tasks.view","tasks/split");
+	    }
+	    if(!configContainsKey("gui.tasks.gridsort")) {
+	        configSetKey("gui.tasks.gridsort","200");
+	    }
+	    if(!configContainsKey("gui.tasks.gridorder")) {
+	        configSetKey("gui.tasks.gridsort","asc");
+	    }
+	    if(!configContainsKey("gui.tasks.interval")) {
+	        configSetKey("gui.tasks.interval",30);
+	    }
+	}
+	
 	if(!configContainsKey("mail.deletemail")) {
 		configSetKey("mail.deletemail",false);	
 	}	
@@ -183,12 +198,12 @@ register("OX_Configuration_Loaded", function() {
 			if(configGetKey("gui.global.autorefresh")*60000==myrel[i]) {
 				isvalid=true;
 				break;
-			}
+			};
 		}
 		if(!isvalid) {
 			configSetKey("gui.global.autorefresh",0);
 		}
-	}
+	};
 	if(!configContainsKey("gui.effects.hover.portal")) {
 		configSetKey("gui.effects.hover.portal",true);
 	}
@@ -218,9 +233,6 @@ register("OX_Configuration_Loaded", function() {
 		configSetKey("gui.categories.local", []);
 		ox.categories.utils.migrateTags();
 	}
-//	if (!configContainsKey("gui.FolderTreeState")) {
-//		configSetKey("gui.FolderTreeState",new Object);
-//	}			
 	if (!configContainsKey("gui.contacts.gridsort") || !isNaN(configGetKey("gui.contacts.gridsort")))   {
 		configSetKey("gui.contacts.gridsort","last_name");
 	}
@@ -230,18 +242,6 @@ register("OX_Configuration_Loaded", function() {
 	if (!configContainsKey("gui.contacts.cardsToViewPerColumn")) {
 		configSetKey("gui.contacts.cardsToViewPerColumn","auto");
 	}
-	if (!configContainsKey("gui.tasks.view")) {
-		configSetKey("gui.tasks.view","tasks/split");
-	}
-	if(!configContainsKey("gui.tasks.gridsort")) {
-		configSetKey("gui.tasks.gridsort","200");
-	}
-	if(!configContainsKey("gui.tasks.gridorder")) {
-		configSetKey("gui.tasks.gridsort","asc");
-	}
-	if(!configContainsKey("gui.tasks.interval")) {
-		configSetKey("gui.tasks.interval",30);
-	}
 	if(!configContainsKey("gui.global.save")) {
 		configSetKey("gui.global.save",1);
 	}
@@ -545,7 +545,6 @@ function configuration_saveObject(force,hidemessage,myok,myerror,optParam) {
 	                success: function (response) {
 	                    // response not empty?
 	                    if (!response && !response.length) {
-	                        openrequests--;
 	                        return;
 	                    }
 	                    data = { "currentTime": response[0].data, 
@@ -559,9 +558,9 @@ function configuration_saveObject(force,hidemessage,myok,myerror,optParam) {
                         ox.api.folder.dispatcher.trigger("modify");
 	                    configuration_changed_fields["timezone"] = false;
 	                    configuration_changed_fields["language"] = false;
-	                    openrequests--;
 	                }
 	            });
+	            myok(successcb);
 	        },
 	        error: myerror
 	    });
@@ -570,7 +569,11 @@ function configuration_saveObject(force,hidemessage,myok,myerror,optParam) {
 	if(configuration_changed_fields["gui"] == true) {
 		saveConfigtoServer("gui","gui",function(){
 		    myok();
-		    triggerEvent("OX_Calendar_Teamlist_Changed");}
+		    triggerEvent("OX_Calendar_Teamlist_Changed");
+		    if (showmessage === true) {
+		    	successcb();
+		    }
+		}
 		,myerror);
 		
 		openrequests++;
