@@ -657,7 +657,12 @@ register("OX_Configuration_Loaded", function () {
         });
 	    
 	    var save_button = new ox.UI.Button(_("Save"));
-        save_button.click = function() { split.saveView(); };
+        save_button.click = function() {
+            var enabled = mail_protocol.enabled;
+            mail_protocol.enable();
+            split.saveView();
+            mail_protocol.setEnabled(enabled);
+        };
 	    buttons.addWidget(save_button);
 	
 	    var cancel_button = new ox.UI.Button(_("Cancel"));
