@@ -289,7 +289,7 @@ register("OX_Configuration_Loaded_Complete", function() {
             });
         },
         save: function(data) {
-            if (!this.checkbox.get()) return;
+            if (!this.checkbox.isVisible || !this.checkbox.get()) return;
             var config = {};
             config[this.service.formDescription[0].name] = data.id;
             ox.JSON.put(AjaxRoot + "/messaging/account/?action=new&session=" +
