@@ -714,7 +714,7 @@ ox.UI.ComboBox.prototype = extend(ox.UI.Selection,
          * Returns the current value of the ComboBox.
          */
         get: function() {
-            return this.combobox.getKey();
+            return this.combobox ? this.combobox.getKey() : this.values[0];
         },
         
         /**
