@@ -738,11 +738,19 @@ function writeNewContact() {
 
 function finalFunction() {
 	
+    function closeWindow() {
+        setTimeout(function() {
+            setBeforeUnload(false);
+            ctrl.close(true);
+        }, 200);
+    }
+    
 	if (modulPopup == "new" || modulPopup == "duplicate") {
 		// new/duplicate
 		setBeforeUnload(false);
-		corewindow.OXContactMapping.createObject(contact_object);
+		corewindow.OXContactMapping.createObject(corewindow.clone(contact_object, window));
 		corewindow.closeContactPopUp(window, clickedItemForSave);
+		closeWindow();
 		
 	} else if(modulPopup = "edit") {
 		// 	edit
@@ -760,6 +768,7 @@ function finalFunction() {
                 })]);
 		}
 		corewindow.closeContactPopUp(window, clickedItemForSave);
+		closeWindow();
     }
 }
 
