@@ -397,6 +397,9 @@ function callback_new(arg) {
 		corewindow.OXInfoStoreMapping.createObject(newInfoItemToWrite);
 		corewindow.triggerEvent("OX_Quota_Update");
 		setTimeout(function () {
+		    if (!ox.api.window.isEmbedded() && ox.browser.Win8 && (ox.browser.IE10 || ox.browser.IE11)) {
+		        ox.api.window.core.triggerEvent("OX_Folder_Objects_Changed", activefolder);
+            }
 		    ctrl.close(true);
 		}, 50);
 	}
@@ -422,6 +425,9 @@ function callback_update(arg) {
 		}
         corewindow.triggerEvent("OX_Quota_Update");
         setTimeout(function () {
+            if (!ox.api.window.isEmbedded() && ox.browser.Win8 && (ox.browser.IE10 || ox.browser.IE11)) {
+                ox.api.window.core.triggerEvent("OX_Folder_Objects_Changed", activefolder);
+            }
             ctrl.close(true);
         },50);
 	}
@@ -521,6 +527,9 @@ function doStoreInfoItem()
 				newServerError(arg);
 			} else {
 			    setTimeout(function () {
+			        if (!ox.api.window.isEmbedded() && ox.browser.Win8 && (ox.browser.IE10 || ox.browser.IE11)) {
+			            ox.api.window.core.triggerEvent("OX_Folder_Objects_Changed", activefolder);
+                    }
 			        ctrl.close(true);
 			    }, 50);
 			}
