@@ -26,7 +26,6 @@ registerModuleView("tasks", "Tasks",5,{x:1,y:1});
 registerPrintView("tasks/list");
 registerPrintView("tasks/split");
 registerPrintView("tasks/split/overview");
-var json = new JSONX(); // argh, very bad making such vars public!
 var completedetailtask;
 var activeTaskId = new Array();
 var tasksTabsList;
@@ -38,10 +37,8 @@ var latestRenderedTask = null;
 var objTaskDetailParticipants = null;
 var refTaskDetailParticipantTab = null;
 var taskParticipantsGrid = null;
-var taskParticipantsGrid2 = false;
 var tasksFolderPath, tasksSearchObject = null;
 
-var tasksSelection = new Selection();
 var tasksSelection2= new Selection2();
 var tmpDetailRequest;
 var oAttachmentGridTask;
@@ -71,7 +68,6 @@ function() {
         tasksEventList = new Array(
                 ['OX_Tasks_Switch_Split_Detail','overview'],
                 ['OX_Tasks_Switch_Split_Detail','participant'],
-                /* ['OX_Tasks_Switch_Split_Detail','history'], */                
                 ['OX_Tasks_Switch_Split_Detail','attachment']
         );        
     }
@@ -94,10 +90,10 @@ function() {
     
     registerView("tasks/list",
         function() {
-            showNode("taskslist");  
-            $("taskslist").style.display=""; 
+            showNode("taskslist");
+            $("taskslist").style.display="";
         }, 
-        function() {            
+        function() {
             var criteria= { "folder_id" : activefolder };
             gridlist.disablehover=!configGetKey("gui.effects.hover.tasks");
             if (tasksSearchObject !== null) {
@@ -113,28 +109,29 @@ function() {
             register("OX_Task_MarkAsDone", tasks_markAsDone);
             if (corewindow.hasFocus) setFocus($("listeTasks"));
          }, 
-         function() {            
+         function() {
             if (gridlist) gridlist.disable();
-            unregister("OX_Add_Flag", fn_add_Tag_tasks);    
+            unregister("OX_Print",printTasks);
             unregister("OX_New_Search", taskSearch);
-            unregister("OX_Print",printTasks);     
+            unregister("OX_Add_Flag", fn_add_Tag_tasks);
+            unregister("OX_Print",printTasks);
             unregister("OX_Delete_Search", taskSearchDelete);
             unregister("OX_Task_MarkAsDone", tasks_markAsDone);
-            latestRenderedTask=null;
             tasksFolderPath.clear();
          },
          function() { 
-            hideNode("taskslist");  
+            hideNode("taskslist");
             $("taskslist").style.display="none";
+            latestRenderedTask = null;
          },
          function(changeFolder) {
-            if (changeFolder != undefined) {
-                trigger("OX_Delete_Search");
-                var criteria = { "folder_id" : activefolder };
-                gridlist.disablehover=!configGetKey("gui.effects.hover.tasks");
-                gridlist.enable(criteria);
-                tasks_setFocus(gridlist);
-            }
+             if (changeFolder != undefined) {
+                 var criteria = { "folder_id" : activefolder };
+                 gridlist.disablehover=!configGetKey("gui.effects.hover.tasks");
+                 gridlist.enable(criteria, false);
+                 tasks_setFocus(gridlist);
+                 triggerEvent("Confirmation_Changed", 0);
+             }
          }
     );
     
@@ -184,7 +181,6 @@ function() {
              }, 
              function() {
                 if (gridsplit) gridsplit.disable();
-                gridsplitTask = false;
                 if (tmpDetailRequest) {
                     OXCache.unregister(tmpDetailRequest.uniqueName);
                     delete(tmpDetailRequest);
@@ -200,15 +196,15 @@ function() {
              },
              function() {
                 latestRenderedTask = null;
-                hideNode("taskssplit");  
+                hideNode("taskssplit");
                 $("taskssplit").style.display="none";
              },
              function(changeFolder) {
                 if (changeFolder != undefined) {
                     var criteria= { "folder_id" : activefolder };
                     gridsplit.disablehover=!configGetKey("gui.effects.hover.tasks");
-                    gridsplit.enable(criteria,false);
-                    tasks_setFocus(gridlist);
+                    gridsplit.enable(criteria, false);
+                    tasks_setFocus(gridsplit);
                     // update confirm button
                     triggerEvent("Confirmation_Changed", 0);
                 }
@@ -298,11 +294,7 @@ function() {
             grid.showFocus();
         }
     }
-    
-//    function cb_object_changed() {
-//        (tasksSelection2.getSelected(), true);
-//    }
-    
+
     function switchToTaskStdView() {
         triggerEvent("OX_Switch_View", configGetKey("gui.tasks.view"));
     }
@@ -322,7 +314,6 @@ function() {
         if (currentpath2[1] == "split") {
           gridsplit.disablehover=!configGetKey("gui.effects.hover.tasks");
           gridsplit.enable(criteria,search,false);
-                
         } else if(currentpath2[1] == "list") {
           gridlist.disablehover=!configGetKey("gui.effects.hover.tasks");
           gridlist.enable(criteria,search,false);
@@ -725,10 +716,8 @@ function() {
     });
 
     
-    function makeGrid(gridName,newlivegrid) {
-        var constructor= newlivegrid ? LiveGrid2 : LiveGrid;
-        var grid = new constructor(temporary.lists.tasks.columns,
-            newlivegrid ? tasksSelection2 : tasksSelection , "tasks");
+    function makeGrid(gridName) {
+        var grid = new LiveGrid2(temporary.lists.tasks.columns, tasksSelection2, "tasks");
         
         var contextData = [];
         var count = Value(), writable = Value(), deletable = Value();
@@ -852,7 +841,7 @@ function() {
                     deleteTask();
                 else
                     triggerEvent("OX_New_Error", 4, _("You do not have write permission for this object."));
-            }       
+            }
         );
         $(gridName + "Header").appendChild(grid.getHeader());
         grid.getTable($(gridName));
@@ -1013,9 +1002,6 @@ function() {
         detailTaskPrint.printDetail(aPrintDetailTask);
     }
 
-    var gridTask = false;
-    var gridsplitTask = false;
-
 })();
 
 function fn_tasks_getDetails(objects, forceUpdate) {   
