@@ -316,10 +316,12 @@ ox.gui.initToolBarCalendar = function ($p) {
 
     // toggles attachment section
     var toggleAttachmentSection = function () {
-        if (currentpath[0] === "calendar") {
+        if (currentpath[0] === "calendar"
+            && upsell.isVisible("infostore")
+            && upsell.isVisible("calendar-attachments")) {
             // get parent tab
             var tab = ox.widgets.toolBar.tabs.calendarEdit;
-            var section = tab.children[3];
+            var section = ox.desktop.getWidget("calendarAttachmentSections");
             var visible = section.isVisible();
             // in team view?
             if (currentpath[2] === "attachment") {
@@ -339,7 +341,7 @@ ox.gui.initToolBarCalendar = function ($p) {
         if (currentpath[0] === "calendar") {
             // get parent tab
             var tab = ox.widgets.toolBar.tabs.calendarEdit;
-            var section = tab.children[2];
+            var section = ox.desktop.getWidget("calendarTeamSection");
             var visible = section.isVisible();
             // in team view?
             if (currentpath[1] === "team") {
