@@ -55,6 +55,16 @@ function createContent() {
                 _("Informs about the current status of E-Mails and appointments without having to display the user interface or another Windows® client."))])
         );
     }
+    
+    if (getProduct("com.openexchange.updater.drive") === true) {
+        jQuery(node).append(
+            newnode("div", { height: "1em" }, 0, []),
+            newnode("div", { fontWeight: "bold" }, 0, [ addTranslated(
+                _("Drive"))]),
+            newnode("div", 0, 0, [addTranslated(
+                _("Data synchronization with your local (Windows) machine. Drive lets you configure the folders to be synchronized."))])
+        );
+    }
     return node;
 }
 
