@@ -1256,7 +1256,7 @@ temporary.services.provide("com.openexchange.oauth.autocreate", {
         this.checkbox.hide();
     },
     save: function(data) {
-        if (!this.checkbox.get()) return;
+        if (!this.checkbox.isVisible || !this.checkbox.get()) return;
         var source = this.source;
         var parent = configGetKey(["folder", source.module]);
         ox.api.folder.getFreeTitle(parent, create, { title: data.displayName });
